@@ -4,6 +4,86 @@
 ## Fixed bug which arose occasionally when using method "dt"
 ## Made "dt" the default as in original LC paper.
 
+#' Model mortality or fertility data using Lee-Carter approach
+#'
+#' Lee-Carter model of mortality or fertility rates. \code{lca} produces a
+#' standard Lee-Carter model by default, although many other options are
+#' available. \code{bms} is a wrapper for \code{lca} and returns a model based
+#' on the Booth-Maindonald-Smith methodology.
+#'
+#'
+#' All mortality or fertility data are assumed to be in matrices of
+#' mortality or fertility rates within \code{data$rate}. Each row is one age group
+#' (assumed to be single years). Each column is one year. The
+#' function produces a model for the \code{series} mortality or fertility rate matrix
+#' within \code{data$rate}. Forecasts from this model can be obtained using \code{\link{forecast.lca}}.
+#'
+#' @param data demogdata object of type \dQuote{mortality} or
+#'   \dQuote{fertility}. Output from read.demogdata.
+#' @param series name of series within data containing mortality or fertility
+#'   values (1x1)
+#' @param years years to include in fit. Default: all available years.
+#' @param ages ages to include in fit. Default: all available ages up to
+#'   \code{max.age}.
+#' @param max.age upper age to include in fit. Ages beyond this are collapsed
+#'   into the upper age group.
+#' @param adjust method to use for adjustment of coefficients \eqn{k_t kt}.
+#'   Possibilities are \dQuote{dxt} (BMS method), \dQuote{dt} (Lee-Carter
+#'   method), \dQuote{e0} (method based on life expectancy) and \dQuote{none}.
+#'   Defaults are \dQuote{dxt} for \code{bms()} and \dQuote{dt} for
+#'   \code{lca()}.
+#' @param chooseperiod If TRUE, it will choose the best fitting period.
+#' @param minperiod Minimum number of years to include in fitting period if
+#'   chooseperiod=TRUE.
+#' @param breakmethod method to use for identifying breakpoints if
+#'   chooseperiod=TRUE. Possibilities are \dQuote{bai} (Bai's method computed
+#'   using \code{\link[strucchange]{breakpoints}} in the strucchange package)
+#'   and \dQuote{bms} (method based on mean deviance ratios described in BMS).
+#' @param scale If TRUE, it will rescale bx and kt so that kt has drift
+#'   parameter = 1.
+#' @param restype method to use for calculating residuals. Possibilities are
+#'   \dQuote{logrates}, \dQuote{rates} and \dQuote{deaths}.
+#' @param interpolate If TRUE, it will estimate any zero mortality or fertility
+#'   rates using the same age group from nearby years.
+#'
+#' @return Object of class \dQuote{lca} with the following components:
+#' \item{label}{Name of region}
+#' \item{age}{Ages from \code{data} object.}
+#' \item{year}{Years from \code{data} object.}
+#' \item{<series>}{Matrix of mortality or fertility data as contained in \code{data}. It takes the name given by the series argument.}
+#' \item{ax}{Average deathrates across fitting period}
+#' \item{bx}{First principal component in Lee-Carter model}
+#' \item{kt}{Coefficient of first principal component}
+#' \item{residuals}{Functional time series of residuals.}
+#' \item{fitted}{Functional time series containing estimated mortality or fertility rates from model}
+#' \item{varprop}{Proportion of variance explained by model.}
+#' \item{y}{The data stored as a functional time series object.}
+#' \item{mdev}{Mean deviance of total and base lack of fit, as described in Booth, Maindonald and Smith.}
+#'
+#' @references Booth, H., Maindonald, J., and Smith, L. (2002) Applying Lee-Carter
+#' under conditions of variable mortality decline. \emph{Population Studies}, \bold{56}, 325-336.
+#'
+#' Lee, R.D., and Carter, L.R. (1992) Modeling and forecasting US mortality. \emph{Journal of
+#'   the American Statistical Association}, \bold{87}, 659-671.
+#'
+#' @author Heather Booth, Leonie Tickle, John Maindonald and Rob J Hyndman.
+#'
+#' @seealso \code{\link{forecast.lca}}, \code{\link{fdm}}
+#' @examples
+#' \dontrun{
+#' france.LC1 <- lca(fr.mort, adjust="e0")
+#' plot(france.LC1)
+#' par(mfrow=c(1,2))
+#' plot(fr.mort,years=1953:2002,ylim=c(-11,1))
+#' plot(forecast(france.LC1,jumpchoice="actual"),ylim=c(-11,1))
+#'
+#' france.bms <- bms(fr.mort, breakmethod="bai")
+#' fcast.bms <- forecast(france.bms)
+#' par(mfrow=c(1,1))
+#' plot(fcast.bms$kt)
+#' }
+#' @keywords models
+#' @export
 lca <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     max.age=100, adjust=c("dt","dxt","e0","none"),
     chooseperiod=FALSE, minperiod=20, breakmethod=c("bai","bms"),
@@ -47,10 +127,10 @@ lca <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     deltat <- year[2]-year[1]
     ages <- data$age
     n <- length(ages)
-    m <- sum(id2>0)
+    m <- length(year)
     mx <- matrix(mx,nrow=n,ncol=m)
-#    n <- nrow(mx) # number of ages
-#    m <- ncol(mx) # number of years
+    colnames(mx) <- year
+    rownames(mx) <- ages
 
     # Interpolate where rates are zero
     if(interpolate)
@@ -178,6 +258,8 @@ lca <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
 
     # Estimate rates from fitted values and get residuals
     logfit <- fitmx(kt,ax,bx,transform=TRUE)
+    colnames(logfit) <- ages
+    rownames(logfit) <- year
     if(restype=="logrates")
     {
         fit <- logfit
@@ -222,7 +304,7 @@ lca <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     #Return
     output <- list(label=data$label,age=ages,year=year, mx=t(mx),
         ax=ax, bx=bx, kt=ts(kt,start=startyear,deltat=deltat), residuals=residuals, fitted=fitted,
-        varprop=svd.mx$d[1]^2/sum(svd.mx$d^2), 
+        varprop=svd.mx$d[1]^2/sum(svd.mx$d^2),
         y=fts(ages,t(mx),start=years[1],frequency=1/deltat,xname="Age",
               yname=ifelse(data$type == "mortality", "Mortality", "Fertility")),
         mdev=mdev)
@@ -234,6 +316,8 @@ lca <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     return(structure(output,class="lca"))
 }
 
+#' @rdname lca
+#' @export
 bms <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     max.age=100, minperiod=20, breakmethod=c("bms","bai"), scale=FALSE, restype=c("logrates","rates","deaths"),
     interpolate=FALSE)
@@ -247,6 +331,7 @@ bms <-  function(data,series=names(data$rate)[1],years=data$year, ages=data$age,
     return(out)
 }
 
+
 estimate.e0 <- function(kt,ax,bx,agegroup,series,startage=0)
 {
     if(length(kt)>1)
@@ -267,6 +352,8 @@ fitmx <- function (kt,ax,bx,transform=FALSE)
         return(exp(logratesfit))
 }
 
+#' @rdname plot.fmforecast
+#' @export
 plot.lca <- function(x,...)
 {
     x$basis <- cbind(x$ax,x$bx)
@@ -276,10 +363,10 @@ plot.lca <- function(x,...)
         xlab <- "kt (adjusted)"
     else
         xlab <- "kt"
-    ftsa::plot.ftsm(x,1,"Age","bx","Year",xlab,mean.lab="ax",...)
+    ftsa::plot.ftsm(x,1,xlab1="Age",ylab1="bx",xlab2="Year",ylab2=xlab,mean.lab="ax",...)
 }
 
-
+#' @export
 print.lca <- function(x,...)
 {
     cat("Lee-Carter analysis\n")
@@ -291,6 +378,8 @@ print.lca <- function(x,...)
     cat(paste("\nPercentage variation explained: ",round(x$varprop*100,1),"%\n",sep=""))
 }
 
+#' @rdname summary.fdm
+#' @export
 summary.lca <- function(object,...)
 {
     print(object)
@@ -302,6 +391,7 @@ summary.lca <- function(object,...)
     printout(fdmMISE(log(object[[4]]),object$fitted$y,age=object$y$x,years=object$year))
 }
 
+
 printout <- function(output)
 {
     junk1 <- cbind(output$ME,output$MSE,output$MPE,output$MAPE)
@@ -319,6 +409,40 @@ printout <- function(output)
 
 # Function performs predictions of k and life expectancy based on leecarter results (in lcaout)
 
+#' Forecast demogdata data using Lee-Carter method.
+#'
+#' The kt coefficients are forecast using a random walk with drift.
+#' The forecast coefficients are then multiplied by bx to
+#' obtain a forecast demographic rate curve.
+#'
+#' @param object Output from \code{\link{lca}}.
+#' @param h Number of years ahead to forecast.
+#' @param se Method used for computation of standard error. Possibilities: \dQuote{innovdrift} (innovations and drift) and \dQuote{innovonly} (innovations only).
+#' @param jumpchoice Method used for computation of jumpchoice. Possibilities: \dQuote{actual} (use actual rates from final year) and \dQuote{fit} (use fitted rates).
+#' @param level Confidence level for prediction intervals.
+#' @param ... Other arguments.
+#'
+#' @return Object of class \code{fmforecast} with the following components:
+#' \item{label}{Region from which the data are taken.}
+#' \item{age}{Ages from \code{object}.}
+#' \item{year}{Years from \code{object}.}
+#' \item{rate}{List of matrices containing forecasts, lower bound and upper bound of prediction intervals.
+#'   Point forecast matrix takes the same name as the series that has been forecast.}
+#' \item{fitted}{Matrix of one-step forecasts for historical data}
+#' Other components included are
+#' \item{e0}{Forecasts of life expectancies (including lower and upper bounds)}
+#' \item{kt.f}{Forecasts of coefficients from the model.}
+#' \item{type}{Data type.}
+#' \item{model}{Details about the fitted model}
+#'
+#' @author Rob J Hyndman
+#' @examples
+#' france.lca <- lca(fr.mort, adjust="e0")
+#' france.fcast <- forecast(france.lca, 50)
+#' plot(france.fcast)
+#' plot(france.fcast,'c')
+#' @keywords models
+#' @export
 forecast.lca <- function(object, h=50, se=c("innovdrift","innovonly"), jumpchoice=c("fit","actual"), level=80, ...)
 {
     se <- match.arg(se)
@@ -363,7 +487,10 @@ forecast.lca <- function(object, h=50, se=c("innovdrift","innovonly"), jumpchoic
 
     # Calculate expected life and mx forecasts
     e0.forecast <- rep(0,h)
-    mx.forecast <- mx.lo.forecast <- mx.hi.forecast <- matrix(0,nrow=nages,ncol=h)
+    mx.forecast <- matrix(0,nrow=nages,ncol=h)
+    colnames(mx.forecast) <- seq(h)
+    rownames(mx.forecast) <- object$age
+    mx.lo.forecast <- mx.hi.forecast <- mx.forecast
     logjumprates <- log(jumprates)
     series <- names(object)[4]
     agegroup <- object$age[4]-object$age[3]
@@ -394,16 +521,21 @@ forecast.lca <- function(object, h=50, se=c("innovdrift","innovonly"), jumpchoic
     return(structure(output,class=c("fmforecast","demogdata")))
 }
 
+#' @rdname residuals.fdm
+#' @export
 fitted.lca <- function(object,...)
 {
     object$fitted
 }
 
+#' @rdname residuals.fdm
+#' @export
 residuals.lca <- function(object,...)
 {
     return(structure(list(x=object$year,y=object$age,z=t(object$residuals$y)),class="fmres"))
 }
 
+
 findroot <- function(FUN,guess,margin,try=1,...)
 {
     # First try in successively larger intervals around best guess
