@@ -1,8 +1,45 @@
+
+#' Updating functional demographic models and coherent functional demographic models.
+#'
+#' \code{update.fmforecast()} updates \code{fdm} forecasts. The argument \code{object} is the output from \code{\link{forecast.fdm}} which has been subsequently modified with new coefficient forecasts. These new forecasts are used when re-calculating the forecast of the mortality or fertility rates, or net migration numbers.
+#' \code{update.fmforecast2()} updates \code{fdmpr} forecasts. The argument \code{object} is the output from \code{\link{forecast.fdmpr}} which has been subsequently modified with new coefficient forecasts.
+#'
+#' @param object Output from either \code{\link{fdm}} or \code{\link{coherentfdm}}.
+#' @param ... Extra arguments currently ignored.
+#'
+#' @return A list of the same class as \code{object}.
+#' @author Rob J Hyndman.
+#' @seealso \code{\link{forecast.fdm}}, \code{\link{forecast.fdmpr}}
+#' @examples
+#' \dontrun{
+#' france.fit <- fdm(fr.mort,order=2)
+#' france.fcast <- forecast(france.fit,50)
+#' # Replace first coefficient model with ARIMA(0,1,2)+drift
+#' france.fcast$coeff[[2]] <- forecast(Arima(france.fit$coeff[,2],
+#'                                           order=c(0,1,2), include.drift=TRUE), h=50, level=80)
+#' france.fcast <- update(france.fcast)
+#'
+#' fr.short <- extract.years(fr.sm,1950:2006)
+#' fr.fit <- coherentfdm(fr.short)
+#' fr.fcast <- forecast(fr.fit)
+#' par(mfrow=c(1,2))
+#' plot(fr.fcast$male)
+#' # Replace first coefficient model in product component with a damped ETS model:
+#' fr.fcast$product$coeff[[2]] <- forecast(ets(fr.fit$product$coeff[,2], damped=TRUE),
+#'                                         h=50, level=80)
+#' fr.fcast <- update(fr.fcast)
+#' plot(fr.fcast$male)
+#' }
+#' @keywords models
+#' @name update
+NULL
+
 # Update fmforecast object
 # Original object from forecast.fdm
 # Assumed that the coefficient forecasts have been subsequently changed
 # Object needs to be updated to reflect those changes.
-
+#' @rdname update
+#' @export
 update.fmforecast <- function(object, ...)
 {
   if(!is.element("fmforecast",class(object)))
@@ -10,7 +47,8 @@ update.fmforecast <- function(object, ...)
   h <- length(object$year)
   nb <- ncol(object$model$basis)
   adjust <- length(object$var$adj.factor) > 1
-  
+  objnames <- dimnames(object$rate[[1]])
+
   # Update in-sample fitted values and errors.
   fitted <- matrix(NA,length(object$model$year),nb)
   meanfcast <- varfcast <- matrix(NA, nrow = h, ncol = nb)
@@ -30,14 +68,15 @@ update.fmforecast <- function(object, ...)
 
   # Update point forecasts
   object$rate[[1]] <- object$model$basis %*% t(meanfcast)
-  
+  dimnames(object$rate[[1]]) <- objnames
+
   # Update forecast variances
   # Only model variance should have changed
   modelvar <- object$model$basis^2 %*% t(varfcast)
   totalvar <- sweep(modelvar, 1, object$var$error + object$var$mean, "+")
-  if (adjust & nb > 1) 
+  if (adjust & nb > 1)
   {
-    object$var$adj.factor <- rowMeans(object$error$y^2, na.rm = TRUE)/totalvar[,1] 
+    object$var$adj.factor <- rowMeans(object$error$y^2, na.rm = TRUE)/totalvar[,1]
     totalvar <- sweep(totalvar, 1, object$var$adj.factor, "*")
   }
   # Add observational variance to total variance
@@ -65,22 +104,23 @@ update.fmforecast <- function(object, ...)
 # Function to combine product and ratio forecasts
 # object is output from forecast.fdmpr, but with modified forecasts
 # This function simply recombines them again.
-
-update.fmforecast2 <- function(object, ...) 
+#' @rdname update
+#' @export
+update.fmforecast2 <- function(object, ...)
 {
   if(!is.element("fmforecast2",class(object)))
     stop("object must be of class fmforecast2")
 
   J <- length(object$ratio)
   ny <- length(object$ratio[[1]]$year)
-  
+
   # GM model
   object$product <- update(object$product)
-  
+
   # Obtain forecasts for each group
 	is.mortality <- (object$product$type=="mortality")
   y <- as.numeric(is.mortality) #=1 for mortality and 0 for migration
-  for (j in 1:J) 
+  for (j in 1:J)
   {
     object$ratio[[j]] <- update(object$ratio[[j]])
     if(is.mortality)
@@ -108,13 +148,13 @@ update.fmforecast2 <- function(object, ...)
 	}
   # Variance of forecasts
   qconf <- 2 * stats::qnorm(0.5 + object$product$coeff[[1]]$level/200)
-  for (j in 1:J) 
+  for (j in 1:J)
   {
     vartotal <- object$product$var$total + object$ratio[[j]]$var$total
     tmp <- qconf * sqrt(vartotal)
     object[[j]]$rate$lower <- InvBoxCox(BoxCox(object[[j]]$rate[[1]],object$product$lambda) - tmp, object$product$lambda)
     object[[j]]$rate$upper <- InvBoxCox(BoxCox(object[[j]]$rate[[1]],object$product$lambda) + tmp, object$product$lambda)
   }
-  
+
   return(object)
 }
